@@ -18,6 +18,6 @@ pub struct Findings<'a> {
 
 impl<'a> Findings<'a> {
 	pub fn recommended_extension(&self) -> Option<String> {
-		mime_extension_lookup(self.mime.clone()).map(|extensions| extensions[0].to_owned())
+		mime_extension_lookup(self.mime.clone()).map(|extensions| extensions[0].clone())
 	}
 }
